# MLOps local test environment
This package is a support role when using the MLOps platform.
With it, you can test preprocessing jobs and machine learning algorithms locally, using 
the in-browser interpreter and debugger, before committing your work to the platform.